==> order-center-api-2.9.0-CLOUD-20240202.024418-11-sources.jar: com/tydic/dyc/oc/service/order/bo/UocOrderReceiveAddressQryServiceRspBo.java <==
package com.tydic.dyc.oc.service.order.bo;

import com.tydic.dyc.base.bo.BaseRspBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;

/**
 * 标题:UocOrderReceiveAddressQryServiceRspBo
 * 说明:
 * 时间:2022/3/23 15:09
 * 作者:田桂银
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class UocOrderReceiveAddressQryServiceRspBo extends BaseRspBo {

    private static final long serialVersionUID = 5418754388975205876L;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "联系人国家编号")
    private String contactCountryId;

    @DocField(value = "联系人国家名称")
    private String contactCountryName;

    @DocField(value = "联系人省份编号")
    private String contactProvinceId;

    @DocField(value = "联系人省份名称")
    private String contactProvinceName;

    @DocField(value = "联系人地市编号")
    private String contactCityId;

    @DocField(value = "联系人地市名称")
    private String contactCityName;

    @DocField(value = "联系人区县编号")
    private String contactCountyId;

    @DocField(value = "联系人区县名称")
    private String contactCountyName;

    @DocField(value = "联系人乡镇编号")
    private String contactTownId;

    @DocField(value = "联系人乡镇名称")
    private String contactTown;

    @DocField(value = "收货人地址")
    private String contactAddress;

    @DocField(value = "联系人公司")
    private String contactCompany;

    @DocField(value = "联系人名称")
    private String contactName;

    @DocField(value = "联系人固话")
    private String contactFixPhone;

    @DocField(value = "联系人邮件")
    private String contactEmail;

    @DocField(value = "联系人手机")
    private String contactMobile;


}

==> order-center-api-3.0.0-CLOUD-20250904.024321-86-sources.jar: com/tydic/dyc/oc/service/order/bo/UocOrderReceiveAddressQryServiceRspBo.java <==
package com.tydic.dyc.oc.service.order.bo;

import com.tydic.dyc.base.bo.BaseRspBo;
import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * 标题:UocOrderReceiveAddressQryServiceRspBo
 * 说明:
 * 时间:2022/3/23 15:09
 * 作者:田桂银
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class UocOrderReceiveAddressQryServiceRspBo extends BaseRspBo {

    private static final long serialVersionUID = 5418754388975205876L;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 联系人国家编号
     */
    private String contactCountryId;

    /**
     * 联系人国家名称
     */
    private String contactCountryName;

    /**
     * 联系人省份编号
     */
    private String contactProvinceId;

    /**
     * 联系人省份名称
     */
    private String contactProvinceName;

    /**
     * 联系人地市编号
     */
    private String contactCityId;

    /**
     * 联系人地市名称
     */
    private String contactCityName;

    /**
     * 联系人区县编号
     */
    private String contactCountyId;

    /**
     * 联系人区县名称
     */
    private String contactCountyName;

    /**
     * 联系人乡镇编号
     */
    private String contactTownId;

    /**
     * 联系人乡镇名称
     */
    private String contactTown;

    /**
     * 收货人地址
     */
    private String contactAddress;

    /**
     * 联系人公司
     */
    private String contactCompany;

    /**
     * 联系人名称
     */
    private String contactName;

    /**
     * 联系人固话
     */
    private String contactFixPhone;

    /**
     * 联系人邮件
     */
    private String contactEmail;

    /**
     * 联系人手机
     */
    private String contactMobile;

    /**
     * 租户id
     */
    private Long sysTenantId;
    private String sysTenantName;


}
